==> ejc-purchase-impl-3.0.0-20250424.091614-5-sources.jar: com/ejianc/business/purchase/bean/SubPlanEntity.java <==
package com.ejianc.business.purchase.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 分包服务采购计划
 * 
 * @author generator
 * 
 */
 @TableName("ejc_purchase_sub_plan")
public class SubPlanEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="project_id")
    private Long projectId; // 项目ID
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="employee_id")
    private Long employeeId; // 编制人
    @TableField(value="employee_name")
    private String employeeName; // 编制人名称
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="plan_name")
    private String planName; // 计划名称
    @TableField(value="org_id")
    private Long orgId; // 组织
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="org_code")
    private String orgCode; // 项目部编码
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 父级组织
    @TableField(value="parent_org_name")
    private String parentOrgName; // 父级组织名称
    @TableField(value="plan_date")
    private Date planDate; // 需用日期
    @TableField(value="dept_name")
    private String deptName; // 需用部门
    @TableField(value="urgent_state")
    private Integer urgentState; // 紧急采购（0-否，1-是）
    @TableField(value="sporadic_state")
    private Integer sporadicState; // 是否零星采购（0-否，1-是）
    @TableField(value="sign_state")
    private Integer signState; // 是否签订合同（0-否，1-是）
    @TableField(value="purchase_type")
    private String purchaseType; // 采购类别
    @TableField(value="purchase_way")
    private String purchaseWay; // 采购方式
    @TableField(value="sub_scope")
    private String subScope; // 分包范围
    @TableField(value="valuation_model")
    private String valuationModel; // 计价模式
    @TableField(value="subject_mny")
    private BigDecimal subjectMny; // 标的金额
    @TableField(value="purchase_date")
    private Date purchaseDate; // 预计采购时间
    @TableField(value="enter_date")
    private Date enterDate; // 计划进场时间
    @TableField(value="pay_scale")
    private String payScale; // 付款比例
    @TableField(value="pay_way")
    private String payWay; // 支付方式
    @TableField(value="certification")
    private String certification; // 分包资质要求
    @TableField(value="duration")
    private Integer duration; // 工期/供货期(月)
    @TableField(value="section_division")
    private String sectionDivision; // 标段划分
    @TableField(value="unit_info")
    private String unitInfo; // 寻源单位信息
    @TableField(value="material_num")
    private String materialNum; // 物资数量
    
    
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getPlanName() {
        return planName;
    }

    public void setPlanName(String planName) {
        this.planName = planName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public Date getPlanDate() {
        return planDate;
    }

    public void setPlanDate(Date planDate) {
        this.planDate = planDate;
    }
    public String getDeptName() {
        return deptName;
    }

    public void setDeptName(String deptName) {
        this.deptName = deptName;
    }
    public Integer getUrgentState() {
        return urgentState;
    }

    public void setUrgentState(Integer urgentState) {
        this.urgentState = urgentState;
    }
    public Integer getSporadicState() {
        return sporadicState;
    }

    public void setSporadicState(Integer sporadicState) {
        this.sporadicState = sporadicState;
    }
    public Integer getSignState() {
        return signState;
    }

    public void setSignState(Integer signState) {
        this.signState = signState;
    }
    public String getPurchaseType() {
        return purchaseType;
    }

    public void setPurchaseType(String purchaseType) {
        this.purchaseType = purchaseType;
    }
    public String getPurchaseWay() {
        return purchaseWay;
    }

    public void setPurchaseWay(String purchaseWay) {
        this.purchaseWay = purchaseWay;
    }
    public String getSubScope() {
        return subScope;
    }

    public void setSubScope(String subScope) {
        this.subScope = subScope;
    }
    public String getValuationModel() {
        return valuationModel;
    }

    public void setValuationModel(String valuationModel) {
        this.valuationModel = valuationModel;
    }
    public BigDecimal getSubjectMny() {
        return subjectMny;
    }

    public void setSubjectMny(BigDecimal subjectMny) {
        this.subjectMny = subjectMny;
    }
    public Date getPurchaseDate() {
        return purchaseDate;
    }

    public void setPurchaseDate(Date purchaseDate) {
        this.purchaseDate = purchaseDate;
    }
    public Date getEnterDate() {
        return enterDate;
    }

    public void setEnterDate(Date enterDate) {
        this.enterDate = enterDate;
    }
    public String getPayScale() {
        return payScale;
    }

    public void setPayScale(String payScale) {
        this.payScale = payScale;
    }
    public String getPayWay() {
        return payWay;
    }

    public void setPayWay(String payWay) {
        this.payWay = payWay;
    }
    public String getCertification() {
        return certification;
    }

    public void setCertification(String certification) {
        this.certification = certification;
    }
    public Integer getDuration() {
        return duration;
    }

    public void setDuration(Integer duration) {
        this.duration = duration;
    }
    public String getSectionDivision() {
        return sectionDivision;
    }

    public void setSectionDivision(String sectionDivision) {
        this.sectionDivision = sectionDivision;
    }
    public String getUnitInfo() {
        return unitInfo;
    }

    public void setUnitInfo(String unitInfo) {
        this.unitInfo = unitInfo;
    }
    public String getMaterialNum() {
        return materialNum;
    }

    public void setMaterialNum(String materialNum) {
        this.materialNum = materialNum;
    }
    
}

==> ejc-purchase-impl-3.0.0-20250424.100325-6-sources.jar: com/ejianc/business/purchase/bean/SubPlanEntity.java <==
package com.ejianc.business.purchase.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 分包服务采购计划
 * 
 * @author generator
 * 
 */
 @TableName("ejc_purchase_sub_plan")
public class SubPlanEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="project_id")
    private Long projectId; // 项目ID
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="employee_id")
    private Long employeeId; // 编制人
    @TableField(value="employee_name")
    private String employeeName; // 编制人名称
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="plan_name")
    private String planName; // 计划名称
    @TableField(value="org_id")
    private Long orgId; // 组织
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="org_code")
    private String orgCode; // 项目部编码
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 父级组织
    @TableField(value="parent_org_name")
    private String parentOrgName; // 父级组织名称
    @TableField(value="plan_date")
    private Date planDate; // 需用日期
    @TableField(value="dept_name")
    private String deptName; // 需用部门
    @TableField(value="urgent_state")
    private Integer urgentState; // 紧急采购（0-否，1-是）
    @TableField(value="sporadic_state")
    private Integer sporadicState; // 是否零星采购（0-否，1-是）
    @TableField(value="sign_state")
    private Integer signState; // 是否签订合同（0-否，1-是）
    @TableField(value="purchase_type")
    private String purchaseType; // 采购类别
    @TableField(value="purchase_way")
    private String purchaseWay; // 采购方式
    @TableField(value="sub_scope")
    private String subScope; // 分包范围
    @TableField(value="valuation_model")
    private String valuationModel; // 计价模式
    @TableField(value="subject_mny")
    private BigDecimal subjectMny; // 标的金额
    @TableField(value="purchase_date")
    private Date purchaseDate; // 预计采购时间
    @TableField(value="enter_date")
    private Date enterDate; // 计划进场时间
    @TableField(value="pay_scale")
    private String payScale; // 付款比例
    @TableField(value="pay_way")
    private String payWay; // 支付方式
    @TableField(value="certification")
    private String certification; // 分包资质要求
    @TableField(value="duration")
    private Integer duration; // 工期/供货期(月)
    @TableField(value="section_division")
    private String sectionDivision; // 标段划分
    @TableField(value="unit_info")
    private String unitInfo; // 寻源单位信息
    @TableField(value="material_num")
    private String materialNum; // 物资数量
    @TableField(value="create_date")
    private Date createDate; // 提制日期
    
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getPlanName() {
        return planName;
    }

    public void setPlanName(String planName) {
        this.planName = planName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public Date getPlanDate() {
        return planDate;
    }

    public void setPlanDate(Date planDate) {
        this.planDate = planDate;
    }
    public String getDeptName() {
        return deptName;
    }

    public void setDeptName(String deptName) {
        this.deptName = deptName;
    }
    public Integer getUrgentState() {
        return urgentState;
    }

    public void setUrgentState(Integer urgentState) {
        this.urgentState = urgentState;
    }
    public Integer getSporadicState() {
        return sporadicState;
    }

    public void setSporadicState(Integer sporadicState) {
        this.sporadicState = sporadicState;
    }
    public Integer getSignState() {
        return signState;
    }

    public void setSignState(Integer signState) {
        this.signState = signState;
    }
    public String getPurchaseType() {
        return purchaseType;
    }

    public void setPurchaseType(String purchaseType) {
        this.purchaseType = purchaseType;
    }
    public String getPurchaseWay() {
        return purchaseWay;
    }

    public void setPurchaseWay(String purchaseWay) {
        this.purchaseWay = purchaseWay;
    }
    public String getSubScope() {
        return subScope;
    }

    public void setSubScope(String subScope) {
        this.subScope = subScope;
    }
    public String getValuationModel() {
        return valuationModel;
    }

    public void setValuationModel(String valuationModel) {
        this.valuationModel = valuationModel;
    }
    public BigDecimal getSubjectMny() {
        return subjectMny;
    }

    public void setSubjectMny(BigDecimal subjectMny) {
        this.subjectMny = subjectMny;
    }
    public Date getPurchaseDate() {
        return purchaseDate;
    }

    public void setPurchaseDate(Date purchaseDate) {
        this.purchaseDate = purchaseDate;
    }
    public Date getEnterDate() {
        return enterDate;
    }

    public void setEnterDate(Date enterDate) {
        this.enterDate = enterDate;
    }
    public String getPayScale() {
        return payScale;
    }

    public void setPayScale(String payScale) {
        this.payScale = payScale;
    }
    public String getPayWay() {
        return payWay;
    }

    public void setPayWay(String payWay) {
        this.payWay = payWay;
    }
    public String getCertification() {
        return certification;
    }

    public void setCertification(String certification) {
        this.certification = certification;
    }
    public Integer getDuration() {
        return duration;
    }

    public void setDuration(Integer duration) {
        this.duration = duration;
    }
    public String getSectionDivision() {
        return sectionDivision;
    }

    public void setSectionDivision(String sectionDivision) {
        this.sectionDivision = sectionDivision;
    }
    public String getUnitInfo() {
        return unitInfo;
    }

    public void setUnitInfo(String unitInfo) {
        this.unitInfo = unitInfo;
    }
    public String getMaterialNum() {
        return materialNum;
    }

    public void setMaterialNum(String materialNum) {
        this.materialNum = materialNum;
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }
}
